@@ -217,15 +217,16 @@ def make_node(
 
     # Generate input OPs for TensorFlow subgraphs
     # For inference testing on OP stand-alone
-    tf_partial_model_inputs: List[tf.keras.Input] = \
-        make_tf_partial_model_inputs(
-            input_tensors=[
-                input_tensor,
-            ]
-        )
-    tf_partial_model_tensors = tf_partial_model_inputs[0] \
-        if tf_partial_model_inputs is not None else None
-    tf_partial_model_outputs = None
+    if kwargs['acc_check']:
+        tf_partial_model_inputs: List[tf.keras.Input] = \
+            make_tf_partial_model_inputs(
+                input_tensors=[
+                    input_tensor,
+                ]
+            )
+        tf_partial_model_tensors = tf_partial_model_inputs[0] \
+            if tf_partial_model_inputs is not None else None
+        tf_partial_model_outputs = None
 
     def tf_partial_model_inference(
         *,
@@ -296,7 +297,7 @@ def make_node(
                     )
                 tf_op_type = tf.nn.convolution
                 ### Partial model
-                if tf_partial_model_inputs is not None:
+                if kwargs['acc_check'] and tf_partial_model_inputs is not None:
                     tf_partial_model_outputs = \
                         [
                             tf.add(
@@ -344,7 +345,7 @@ def make_node(
                         )
                     tf_op_type = 'GroupedConvolution1D'
                     ### Partial model
-                    if tf_partial_model_inputs is not None:
+                    if kwargs['acc_check'] and tf_partial_model_inputs is not None:
                         tf_partial_model_outputs = \
                             [
                                 tf.add(
@@ -387,7 +388,7 @@ def make_node(
                         )
                     tf_op_type = 'GroupedConvolution2D'
                     ### Partial model
-                    if tf_partial_model_inputs is not None:
+                    if kwargs['acc_check'] and tf_partial_model_inputs is not None:
                         tf_partial_model_outputs = \
                             [
                                 tf.add(
@@ -432,7 +433,7 @@ def make_node(
                 #         )
                 #     tf_op_type = 'GroupedConvolution3D'
                 #     ### Partial model
-                #     if tf_partial_model_inputs is not None:
+                #     if kwargs['acc_check'] and tf_partial_model_inputs is not None:
                 #         tf_partial_model_outputs = \
                 #             [
                 #                 tf.add(
@@ -479,7 +480,7 @@ def make_node(
                         )
                     tf_op_type = tf.nn.convolution
                     ### Partial model
-                    if tf_partial_model_inputs is not None:
+                    if kwargs['acc_check'] and tf_partial_model_inputs is not None:
                         partial_input_tensor_splits = tf.split(tf_partial_model_tensors, num_or_size_splits=group, axis=-1)
                         partial_weight_splits = tf.split(input_weights, num_or_size_splits=group, axis=-1)
                         tf_partial_model_outputs = \
@@ -523,7 +524,7 @@ def make_node(
                 )
             tf_op_type = tf.nn.depthwise_conv2d
             ### Partial model
-            if tf_partial_model_inputs is not None:
+            if kwargs['acc_check'] and tf_partial_model_inputs is not None:
                 tf_partial_model_outputs = \
                     [
                         tf.add(
@@ -558,7 +559,7 @@ def make_node(
                     )
                 tf_op_type = tf.nn.convolution
                 ### Partial model
-                if tf_partial_model_inputs is not None:
+                if kwargs['acc_check'] and tf_partial_model_inputs is not None:
                     tf_partial_model_outputs = \
                         [
                             tf.nn.convolution(
@@ -600,7 +601,7 @@ def make_node(
                         )(input_tensor)
                     tf_op_type = 'GroupedConvolution1D'
                     ### Partial model
-                    if tf_partial_model_inputs is not None:
+                    if kwargs['acc_check'] and tf_partial_model_inputs is not None:
                         tf_partial_model_outputs = \
                             [
                                 Conv1D(
@@ -637,7 +638,7 @@ def make_node(
                         )(input_tensor)
                     tf_op_type = 'GroupedConvolution2D'
                     ### Partial model
-                    if tf_partial_model_inputs is not None:
+                    if kwargs['acc_check'] and tf_partial_model_inputs is not None:
                         tf_partial_model_outputs = \
                             [
                                 Conv2D(
@@ -676,7 +677,7 @@ def make_node(
                 #         )(input_tensor)
                 #     tf_op_type = 'GroupedConvolution3D'
                 #     ### Partial model
-                #     if tf_partial_model_inputs is not None:
+                #     if kwargs['acc_check'] and tf_partial_model_inputs is not None:
                 #         tf_partial_model_outputs = \
                 #             [
                 #                 Conv3D(
@@ -717,7 +718,7 @@ def make_node(
                         )
                     tf_op_type = tf.nn.convolution
                     ### Partial model
-                    if tf_partial_model_inputs is not None:
+                    if kwargs['acc_check'] and tf_partial_model_inputs is not None:
                         partial_input_tensor_splits = tf.split(tf_partial_model_tensors, num_or_size_splits=group, axis=-1)
                         partial_weight_splits = tf.split(input_weights, num_or_size_splits=group, axis=-1)
                         tf_partial_model_outputs = \
@@ -755,7 +756,7 @@ def make_node(
                 )
             tf_op_type = tf.nn.depthwise_conv2d
             ### Partial model
-            if tf_partial_model_inputs is not None:
+            if kwargs['acc_check'] and tf_partial_model_inputs is not None:
                 tf_partial_model_outputs = \
                     [
                         tf.nn.depthwise_conv2d(
