@@ -179,11 +179,12 @@ def make_node(
 
     # Generate input OPs for TensorFlow subgraphs
     # For inference testing on OP stand-alone
-    tf_partial_model_inputs: List[tf.keras.Input] = \
-        make_tf_partial_model_inputs(
-            input_tensors=[input_tensor]
-        )
-    tf_partial_model_outputs = None
+    if kwargs['acc_check']:
+        tf_partial_model_inputs: List[tf.keras.Input] = \
+            make_tf_partial_model_inputs(
+                input_tensors=[input_tensor]
+            )
+        tf_partial_model_outputs = None
 
     # Generation of TF OP
     ### Overall model
@@ -196,7 +197,7 @@ def make_node(
             **kwargs,
         )
     ### Partial model
-    if tf_partial_model_inputs is not None:
+    if kwargs['acc_check'] and tf_partial_model_inputs is not None:
         tf_partial_model_outputs = \
             [
                 transpose_with_flexing_deterrence(
